/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.group;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.Optional;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.operator.keycloak.OzgCloudCustomResourceStatus;

class KeycloakGroupReconcilerTest {

	@Spy
	@InjectMocks
	private KeycloakGroupReconciler reconciler;

	@Mock
	private KeycloakGroupService service;

	@Mock
	private KeycloakGroupPreconditionService preconditionService;

	@Nested
	class TestReconcile {

		private static final String ERROR_MESSAGE = "ErrorMessage";
		private static final OzgCloudKeycloakGroup KEYCLOAK_GROUP = OzgCloudKeycloakGroupTestFactory.create();

		@Test
		void shouldCallServiceAddGroup() {
			reconciler.reconcile(KEYCLOAK_GROUP, null);

			verify(service).createGroup(KEYCLOAK_GROUP.getSpec(), OzgCloudKeycloakGroupTestFactory.METADATA_NAMESPACE);
		}

		@Test
		void shouldReturnUpdateStatus() {
			var response = reconciler.reconcile(KEYCLOAK_GROUP, null);

			assertThat(response.getResource()).isNotNull();
		}

		@Test
		void shouldSetStatusOk() {
			var response = reconciler.reconcile(KEYCLOAK_GROUP, null);

			assertThat(response.getResource().getStatus().getStatus()).isEqualTo(OzgCloudCustomResourceStatus.OK);
		}

		@Test
		void shouldReturnInProgressStatusIfPreconditionsNotMet() {
			when(preconditionService.getReconcilePreconditionErrors(any())).thenReturn(Optional.of(ERROR_MESSAGE));

			var response = reconciler.reconcile(KEYCLOAK_GROUP, null);

			assertThat(response.getResource().getStatus().getStatus()).isEqualTo(OzgCloudCustomResourceStatus.IN_PROGRESS);
		}
	}
}
